*[data-v-536d087a]{will-change:height;transform:translateZ(0);backface-visibility:hidden;perspective:1000px}.expand-enter-active,.expand-leave-active{transition:height .5s ease-in-out;overflow:hidden}.expand-enter,.expand-leave-to{height:0}
